# -*- coding: utf-8 -*-
""" Top-level package for sulphur_peak."""
from pathlib import Path

from opsdata_sulphur_peak.version import __version__

source_path = Path(__file__).parent / "sulphur_peak"
